<?php
// Push CSS to the document
//
// The css() method provides a quick and convenient way to attach stylesheets. 
// 
// 1. The name of the stylesheet to be pushed to the document (file extension is optional). 
//    If no name is provided, the name of the component or plugin will be used. For instance, 
//    if called within a view of the component com_tags, the system will look for a stylesheet named tags.css.
// 
// 2. The name of the extension to look for the stylesheet. For components, this will be 
//    the component name (e.g., com_tags). For plugins, this is the name of the plugin folder 
//    and requires the third argument be passed to the method.
//
// Method chaining is also allowed.
// $this->css()  
//      ->css('another');

$this->css();

// Similarly, a js() method is available for pushing javascript assets to the document.
// The arguments accepted are the same as the css() method described above.
//
// $this->js();

$current = null;
?>
<header id="content-header">
	<h2><?php echo JText::_('COM_DRWHO'); ?>: <?php echo JText::_('COM_DRWHO_CHARACTERS'); ?></h2>

	<div id="content-header-extra">
		<p>
			<a class="icon-prev btn" href="<?php echo JRoute::_('index.php?option=' . $this->option); ?>"><?php echo JText::_('COM_DRWHO_MAIN'); ?></a>
		</p>
	</div>
</header>

<section class="main section">
	<form class="section-inner" action="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller); ?>" method="get">
		<div class="container">
			<fieldset>
				<select name="season">
					<option value=""><?php echo JText::_('COM_DRWHO_SEASONS_ALL'); ?></option>
					<?php foreach ($this->model->seasons() as $season) { ?>
						<?php
						if ($this->filters['season'] == $season->get('id'))
						{
							$current = $season;
						}
						?>
						<option<?php if ($this->filters['season'] == $season->get('id')) { echo ' selected="selected"'; } ?> value="<?php echo $season->get('alias'); ?>"><?php echo $this->escape($season->get('title')); ?></option>
					<?php } ?>
				</select>
				<input type="submit" value="<?php echo JText::_('COM_DRWHO_GO'); ?>" />
				<?php
				/*if ($current)
				{
					echo '<span class="main-doctor">' . $this->escape($current->doctor()->get('name'));

					if ($current->doctor()->regenerate())
					{
						echo ' -> ' . $this->escape($current->doctor()->get('name'));
					}
					echo '</span>';
				}*/
				?>
			</fieldset>

			<table class="entries">
				<caption><?php echo JText::_('COM_DRWHO_CHARACTERS'); ?></caption>
				<thead>
					<tr>
						<th><?php echo JText::_('COM_DRWHO_COL_ID'); ?></th>
						<th><?php echo JText::_('COM_DRWHO_COL_NAME'); ?></th>
						<th><?php echo JText::_('COM_DRWHO_COL_FRIEND'); ?></th>
						<th><?php echo JText::_('COM_DRWHO_COL_ENEMY'); ?></th>
						<th><?php echo JText::_('COM_DRWHO_COL_THE_DOCTOR'); ?></th>
						<?php if ($this->model->access('edit')) { ?>
							<th></th>
						<?php } ?>
					</tr>
				</thead>
			<?php if ($this->model->access('create')) { ?>
				<tfoot>
					<tr>
						<td colspan="<?php echo ($this->model->access('edit') ? '6' : '5'); ?>">
							<a class="icon-add btn" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=add'); ?>">
								<?php echo JText::_('COM_DRWHO_NEW'); ?>
							</a>
						</td>
					</tr>
				</tfoot>
			<?php } ?>
				<tbody>
				<?php foreach ($this->records as $record) { ?>
					<tr>
						<th>
							<?php echo $this->escape($record->get('id')); ?>
						</th>
						<td>
							<a href="<?php echo JRoute::_($record->link()); ?>">
								<?php echo $this->escape($record->get('name')); ?>
							</a>
						</td>
						<td>
							<?php echo $record->isFriend() ? '<span class="icon-yes">' . JText::_('JYES') . '</span>' : ''; ?>
						</td>
						<td>
							<?php echo $record->isEnemy() ? '<span class="icon-yes">' . JText::_('JYES') . '</span>' : ''; ?>
						</td>
						<td>
							<?php echo $record->isDoctor() ? '<span class="icon-yes">' . JText::_('JYES') . '</span>' : '<span class="icon-no">' . JText::_('JNO') . '</span>'; ?>
						</td>
						<?php if ($this->model->access('edit')) { ?>
							<td>
								<a class="icon-edit btn" href="<?php echo JRoute::_($record->link('edit')); ?>">
									<?php echo JText::_('JACTION_EDIT'); ?>
								</a>
								<a class="icon-delete btn" href="<?php echo JRoute::_($record->link('delete')); ?>">
									<?php echo JText::_('JACTION_DELETE'); ?>
								</a>
							</td>
						<?php } ?>
					</tr>
				<?php } ?>
				</tbody>
			</table>

			<?php 
			jimport('joomla.html.pagination');
			$pageNav = new JPagination(
				$this->total, 
				$this->filters['start'], 
				$this->filters['limit']
			);
			$pageNav->setAdditionalUrlParam('season', $this->filters['season']);

			echo $pageNav->getListFooter();

			JPluginHelper::importPlugin('drwho');
			$dispatcher = JDispatcher::getInstance();

			$results = $dispatcher->trigger('onAfterDisplay');
			echo implode("\n", $results);
			?>
		</div>
	</form>
</section>